function [MeanLogPredScore,BandCoverageProbs,PostProbCoverage]=DistPredAccuracy(LogPredScore,BandCoverage,MSSESubsetVars,EvalHorizons,CoverProb)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE:      Computes the log predictive density score (LPDS) along with empirical coverage rates of predictive intervals.
%
% INPUT:        LogPredScore
%               BandCoverage
%               EvalHorizons
%               CoverProb
%
% OUTPUT:       MeanLogPredScore
%               BandCoverageProbs
%               PostProbCoverage
%
% AUTHOR:       Mattias Villani, Research Department, Sveriges Riksbank and
%               Department of Statistics, Stockholm University. 
%               E-mail: mattias.villani@riksbank.se
%
% REVISED:      2005-04-27
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


NEvalHorizons=length(EvalHorizons);
NCoverProb=length(CoverProb);
% Log Predictive Score
for u=1:length(MSSESubsetVars)
    for j=1:NEvalHorizons
        if size(LogPredScore,1)>0
            MeanLogPredScore(j,u)=mean(LogPredScore(LogPredScore(:,j,u)~=0,j,u));
        else
            MeanLogPredScore=nan;
        end
    end
end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%% Accuracy of forecast intervals %%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if NCoverProb>0 && ~isempty(BandCoverage)
    NPredVars=size(BandCoverage,2);
    BandCoverageProbs=zeros(size(BandCoverage,3),NPredVars,size(BandCoverage,4));
    PostProbCoverage=nan*ones(3,NPredVars,NCoverProb);
    for CoverProbCount=1:NCoverProb
        for j=1:NEvalHorizons
            for Var=1:NPredVars
                HitSequence=BandCoverage(BandCoverage(:,Var,j,CoverProbCount)~=0,Var,j,CoverProbCount)>0;
                if EvalHorizons(j)==1
                    [ModelPosterior,BernoulliSummaryBayes,MarkovSummaryBayes,MLEBernoulli,MLEMarkov,LogLR,PVal]=DichoSeqTest(HitSequence,CoverProb(NCoverProb-CoverProbCount+1),1,5,0,0.95);
                    PostProbCoverage(:,Var,NCoverProb-CoverProbCount+1)=ModelPosterior';
                end
                BandCoverageProbs(j,Var,NCoverProb-CoverProbCount+1)=mean(HitSequence);
            end
        end
    end
else
    BandCoverageProbs=nan;
    PostProbCoverage=nan;
end    

